# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.0a3

([Full Changelog](https://github.com/jupyterlab/jupyter-builder/compare/v0.1.0a2...464a12d6a8288e06646f0c364ee1477d643c7261))

### Maintenance and upkeep improvements

- Bump ruff from 0.4.7 to 0.5.5 in the pip group across 1 directory [#24](https://github.com/jupyterlab/jupyter-builder/pull/24) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyter-builder/graphs/contributors?from=2024-07-29&to=2024-07-30&type=c))

[@dependabot](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyter-builder+involves%3Adependabot+updated%3A2024-07-29..2024-07-30&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.0a2

([Full Changelog](https://github.com/jupyterlab/jupyter-builder/compare/ac6bb51518d309b96658dc45784f4d47a7cd559c...02764ce51fd919bdb5739e06d545656ee0e5b2c9))

### Enhancements made

- Include jlpm within this package (Issue #15) [#20](https://github.com/jupyterlab/jupyter-builder/pull/20) ([@cronan03](https://github.com/cronan03))
- Watch feature and tests [#18](https://github.com/jupyterlab/jupyter-builder/pull/18) ([@cronan03](https://github.com/cronan03))
- Build feature and Tests [#13](https://github.com/jupyterlab/jupyter-builder/pull/13) ([@cronan03](https://github.com/cronan03))
- Develop command working [#11](https://github.com/jupyterlab/jupyter-builder/pull/11) ([@cronan03](https://github.com/cronan03))

### Bugs fixed

- Comment npm related release hook [#25](https://github.com/jupyterlab/jupyter-builder/pull/25) ([@fcollonval](https://github.com/fcollonval))

### Maintenance and upkeep improvements

- Scaffolding for adding a npm package and setting up the releaser [#23](https://github.com/jupyterlab/jupyter-builder/pull/23) ([@fcollonval](https://github.com/fcollonval))
- Bump ruff from 0.4.2 to 0.4.7 in the pip group [#9](https://github.com/jupyterlab/jupyter-builder/pull/9) ([@dependabot](https://github.com/dependabot))
- Bump ruff from 0.3.4 to 0.4.2 in the pip group [#7](https://github.com/jupyterlab/jupyter-builder/pull/7) ([@dependabot](https://github.com/dependabot))
- Bump apache/skywalking-eyes from 97538682f556b56cc7422ece660d8d7e6c4fb013 to cd7b195c51fd3d6ad52afceb760719ddc6b3ee91 in the actions group [#6](https://github.com/jupyterlab/jupyter-builder/pull/6) ([@dependabot](https://github.com/dependabot))
- Bump the pip group with 1 update [#5](https://github.com/jupyterlab/jupyter-builder/pull/5) ([@dependabot](https://github.com/dependabot))
- Bump the actions group with 1 update [#4](https://github.com/jupyterlab/jupyter-builder/pull/4) ([@dependabot](https://github.com/dependabot))
- Add skeleton [#2](https://github.com/jupyterlab/jupyter-builder/pull/2) ([@fcollonval](https://github.com/fcollonval))

### Documentation improvements

- Documentation  [#22](https://github.com/jupyterlab/jupyter-builder/pull/22) ([@cronan03](https://github.com/cronan03))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyter-builder/graphs/contributors?from=2024-03-04&to=2024-07-29&type=c))

[@cronan03](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyter-builder+involves%3Acronan03+updated%3A2024-03-04..2024-07-29&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyter-builder+involves%3Adependabot+updated%3A2024-03-04..2024-07-29&type=Issues) | [@fcollonval](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyter-builder+involves%3Afcollonval+updated%3A2024-03-04..2024-07-29&type=Issues) | [@kloczek](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyter-builder+involves%3Akloczek+updated%3A2024-03-04..2024-07-29&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyter-builder+involves%3Awelcome+updated%3A2024-03-04..2024-07-29&type=Issues)
